@@ -86,13 +86,15 @@ def add_todo(task_text, expected_duration, workspace_id, project_name):
     me = client.users.me()
     
     if workspace_id is None: workspace_id = me['workspaces'][0]['gid']
+    
+    
     projects = list(client.projects.get_projects_for_workspace(workspace_id))
-    if project_name is None:
-        project_name = 'Daily'
-        project_id = [ w['gid'] for w in projects if w['name'] == project_name][0]
-    else:
+    if project_name is 0:
         # here project_name is id
         project_id = projects[int(project_name)]['gid']
+    else:
+        project_name = 'Daily'
+        project_id = [ w['gid'] for w in projects if w['name'] == project_name][0]
         
     # docs https://developers.asana.com/docs/create-a-task
         
