@@ -1,4 +1,16 @@
 #/bin/python
+'''
+TODO: fix
+
+botocore.exceptions.ClientError: An error occurred (InvalidPermission.Duplicate) 
+when calling the AuthorizeSecurityGroupIngress operation: the specified rule "peer: 86.16.93.195/32, TCP, from port: 8501, 
+to port: 8501, ALLOW" already exists
+
+  File "/Users/jlangr/code/data-toolkit/dt/controllers/base.py", line 101, in sg
+    update_sg_to_ip(sg_name=sg_name, profile=profile,
+  File "/Users/jlangr/code/data-toolkit/dt/ext/aws_sg.py", line 111, in update_sg_to_ip
+    data = ec2.authorize_security_group_ingress(
+'''
 
 import boto3
 import pandas as pd
@@ -81,17 +93,22 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         ports = [ int(i.split(':')[0]) for i in items ] 
 
     # TODO: allow for more than just 1 port setting
-    target_ports = [ s['ToPort']==ports[0] for s in sg_res.ip_permissions if 'ToPort' in s.keys()]
-    for i in range(len(target_ports)): 
-        if target_ports[i]: del sg_res.ip_permissions[i]
-
-    
+    target_ports = [ [ s['ToPort']==p for p in ports ]
+                    for s in sg_res.ip_permissions if 'ToPort' in s.keys()]
+    # flatten target_ports list take all True values and merge into one list
+    # [[True, False, False],[False, False True]] -> [True, False, True]
+    target_ports = [ any(i) for i in zip(*target_ports) ]
+     
     # loop using description to only remove already existing and replace them later
     # effectiely overwriting them
-    ip_ranges_to_revoke = [ s for s in sg_res.ip_permissions[0]['IpRanges'] if check_if_exists(s, list(descriptions.values())) ]
-    permissions_to_revoke = [{ 
-        **sg_res.ip_permissions[0],
-        'IpRanges': ip_ranges_to_revoke }]
+    permissions_to_revoke = []
+    for i in range(len(sg_res.ip_permissions)):
+        if target_ports[i]:
+            ipr = sg_res.ip_permissions[i]
+            ip_ranges_to_revoke = [ s for s in ipr['IpRanges'] if check_if_exists(s, list(descriptions.values())) ]
+            permissions_to_revoke.append({ 
+                **ipr,
+                'IpRanges': ip_ranges_to_revoke })
 
     # Removes all relevant permissions from this group (originally as `jakub`)
     if sg_res.ip_permissions!=[] and permissions_to_revoke==[]:
